@@ -284,9 +284,6 @@ class _layline():
 
 
 class laydb():
-    WriteData = write_pickle
-    ReadData = pickle_loads
-    path = libpath
 
     def __init__(self, folder, factory=None, columns=('*', ), _sort=None):
         if type(folder) is _WindowsPath:
@@ -311,7 +308,13 @@ class laydb():
             columns = self.columns if columns is undefined else columns,
             _sort = self._sort if _sort is undefined else _sort,
         )
-
+    
+    def WriteData(self, fpath, data):  # data: Python对象
+        return write_pickle(fpath, data)
+    
+    def ReadData(self, data):  # type(data) is bytes
+        return pickle_loads(data)
+    
     def order(self, **rule): return self._copy(_sort={**self._sort, **rule})  # **rule必须放在后面, 才能覆盖旧规则
     def reset_order(self, **rule): return self._copy(_sort=rule)
 
